# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceTypesResult',
    'AwaitableGetInstanceTypesResult',
    'get_instance_types',
    'get_instance_types_output',
]

@pulumi.output_type
class GetInstanceTypesResult:
    """
    A collection of values returned by getInstanceTypes.
    """
    def __init__(__self__, availability_zone=None, cpu_core_count=None, eni_amount=None, gpu_amount=None, gpu_spec=None, id=None, ids=None, image_id=None, instance_charge_type=None, instance_type=None, instance_type_family=None, instance_types=None, is_outdated=None, kubernetes_node_role=None, memory_size=None, minimum_eni_ipv6_address_quantity=None, minimum_eni_private_ip_address_quantity=None, network_type=None, output_file=None, sorted_by=None, spot_strategy=None, system_disk_category=None):
        if availability_zone and not isinstance(availability_zone, str):
            raise TypeError("Expected argument 'availability_zone' to be a str")
        pulumi.set(__self__, "availability_zone", availability_zone)
        if cpu_core_count and not isinstance(cpu_core_count, int):
            raise TypeError("Expected argument 'cpu_core_count' to be a int")
        pulumi.set(__self__, "cpu_core_count", cpu_core_count)
        if eni_amount and not isinstance(eni_amount, int):
            raise TypeError("Expected argument 'eni_amount' to be a int")
        pulumi.set(__self__, "eni_amount", eni_amount)
        if gpu_amount and not isinstance(gpu_amount, int):
            raise TypeError("Expected argument 'gpu_amount' to be a int")
        pulumi.set(__self__, "gpu_amount", gpu_amount)
        if gpu_spec and not isinstance(gpu_spec, str):
            raise TypeError("Expected argument 'gpu_spec' to be a str")
        pulumi.set(__self__, "gpu_spec", gpu_spec)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if instance_charge_type and not isinstance(instance_charge_type, str):
            raise TypeError("Expected argument 'instance_charge_type' to be a str")
        pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if instance_type_family and not isinstance(instance_type_family, str):
            raise TypeError("Expected argument 'instance_type_family' to be a str")
        pulumi.set(__self__, "instance_type_family", instance_type_family)
        if instance_types and not isinstance(instance_types, list):
            raise TypeError("Expected argument 'instance_types' to be a list")
        pulumi.set(__self__, "instance_types", instance_types)
        if is_outdated and not isinstance(is_outdated, bool):
            raise TypeError("Expected argument 'is_outdated' to be a bool")
        pulumi.set(__self__, "is_outdated", is_outdated)
        if kubernetes_node_role and not isinstance(kubernetes_node_role, str):
            raise TypeError("Expected argument 'kubernetes_node_role' to be a str")
        pulumi.set(__self__, "kubernetes_node_role", kubernetes_node_role)
        if memory_size and not isinstance(memory_size, float):
            raise TypeError("Expected argument 'memory_size' to be a float")
        pulumi.set(__self__, "memory_size", memory_size)
        if minimum_eni_ipv6_address_quantity and not isinstance(minimum_eni_ipv6_address_quantity, int):
            raise TypeError("Expected argument 'minimum_eni_ipv6_address_quantity' to be a int")
        pulumi.set(__self__, "minimum_eni_ipv6_address_quantity", minimum_eni_ipv6_address_quantity)
        if minimum_eni_private_ip_address_quantity and not isinstance(minimum_eni_private_ip_address_quantity, int):
            raise TypeError("Expected argument 'minimum_eni_private_ip_address_quantity' to be a int")
        pulumi.set(__self__, "minimum_eni_private_ip_address_quantity", minimum_eni_private_ip_address_quantity)
        if network_type and not isinstance(network_type, str):
            raise TypeError("Expected argument 'network_type' to be a str")
        pulumi.set(__self__, "network_type", network_type)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if sorted_by and not isinstance(sorted_by, str):
            raise TypeError("Expected argument 'sorted_by' to be a str")
        pulumi.set(__self__, "sorted_by", sorted_by)
        if spot_strategy and not isinstance(spot_strategy, str):
            raise TypeError("Expected argument 'spot_strategy' to be a str")
        pulumi.set(__self__, "spot_strategy", spot_strategy)
        if system_disk_category and not isinstance(system_disk_category, str):
            raise TypeError("Expected argument 'system_disk_category' to be a str")
        pulumi.set(__self__, "system_disk_category", system_disk_category)

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> Optional[str]:
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="cpuCoreCount")
    def cpu_core_count(self) -> Optional[int]:
        """
        Number of CPU cores.
        """
        return pulumi.get(self, "cpu_core_count")

    @property
    @pulumi.getter(name="eniAmount")
    def eni_amount(self) -> Optional[int]:
        """
        The maximum number of network interfaces that an instance type can be attached to.
        """
        return pulumi.get(self, "eni_amount")

    @property
    @pulumi.getter(name="gpuAmount")
    def gpu_amount(self) -> Optional[int]:
        return pulumi.get(self, "gpu_amount")

    @property
    @pulumi.getter(name="gpuSpec")
    def gpu_spec(self) -> Optional[str]:
        return pulumi.get(self, "gpu_spec")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of instance type IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[str]:
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> Optional[str]:
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[str]:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="instanceTypeFamily")
    def instance_type_family(self) -> Optional[str]:
        return pulumi.get(self, "instance_type_family")

    @property
    @pulumi.getter(name="instanceTypes")
    def instance_types(self) -> Sequence['outputs.GetInstanceTypesInstanceTypeResult']:
        """
        A list of image types. Each element contains the following attributes:
        """
        return pulumi.get(self, "instance_types")

    @property
    @pulumi.getter(name="isOutdated")
    def is_outdated(self) -> Optional[bool]:
        return pulumi.get(self, "is_outdated")

    @property
    @pulumi.getter(name="kubernetesNodeRole")
    def kubernetes_node_role(self) -> Optional[str]:
        return pulumi.get(self, "kubernetes_node_role")

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> Optional[float]:
        """
        Size of memory, measured in GB.
        """
        return pulumi.get(self, "memory_size")

    @property
    @pulumi.getter(name="minimumEniIpv6AddressQuantity")
    def minimum_eni_ipv6_address_quantity(self) -> Optional[int]:
        return pulumi.get(self, "minimum_eni_ipv6_address_quantity")

    @property
    @pulumi.getter(name="minimumEniPrivateIpAddressQuantity")
    def minimum_eni_private_ip_address_quantity(self) -> Optional[int]:
        return pulumi.get(self, "minimum_eni_private_ip_address_quantity")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> Optional[str]:
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="sortedBy")
    def sorted_by(self) -> Optional[str]:
        return pulumi.get(self, "sorted_by")

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> Optional[str]:
        return pulumi.get(self, "spot_strategy")

    @property
    @pulumi.getter(name="systemDiskCategory")
    def system_disk_category(self) -> Optional[str]:
        return pulumi.get(self, "system_disk_category")


class AwaitableGetInstanceTypesResult(GetInstanceTypesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceTypesResult(
            availability_zone=self.availability_zone,
            cpu_core_count=self.cpu_core_count,
            eni_amount=self.eni_amount,
            gpu_amount=self.gpu_amount,
            gpu_spec=self.gpu_spec,
            id=self.id,
            ids=self.ids,
            image_id=self.image_id,
            instance_charge_type=self.instance_charge_type,
            instance_type=self.instance_type,
            instance_type_family=self.instance_type_family,
            instance_types=self.instance_types,
            is_outdated=self.is_outdated,
            kubernetes_node_role=self.kubernetes_node_role,
            memory_size=self.memory_size,
            minimum_eni_ipv6_address_quantity=self.minimum_eni_ipv6_address_quantity,
            minimum_eni_private_ip_address_quantity=self.minimum_eni_private_ip_address_quantity,
            network_type=self.network_type,
            output_file=self.output_file,
            sorted_by=self.sorted_by,
            spot_strategy=self.spot_strategy,
            system_disk_category=self.system_disk_category)


def get_instance_types(availability_zone: Optional[str] = None,
                       cpu_core_count: Optional[int] = None,
                       eni_amount: Optional[int] = None,
                       gpu_amount: Optional[int] = None,
                       gpu_spec: Optional[str] = None,
                       image_id: Optional[str] = None,
                       instance_charge_type: Optional[str] = None,
                       instance_type: Optional[str] = None,
                       instance_type_family: Optional[str] = None,
                       is_outdated: Optional[bool] = None,
                       kubernetes_node_role: Optional[str] = None,
                       memory_size: Optional[float] = None,
                       minimum_eni_ipv6_address_quantity: Optional[int] = None,
                       minimum_eni_private_ip_address_quantity: Optional[int] = None,
                       network_type: Optional[str] = None,
                       output_file: Optional[str] = None,
                       sorted_by: Optional[str] = None,
                       spot_strategy: Optional[str] = None,
                       system_disk_category: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceTypesResult:
    """
    This data source provides the ECS instance types of Alibaba Cloud.

    > **NOTE:** By default, only the upgraded instance types are returned. If you want to get outdated instance types, you must set `is_outdated` to true.

    > **NOTE:** If one instance type is sold out, it will not be exported.

    > **NOTE:** Available since v1.0.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.get_zones(available_resource_creation="VSwitch")
    # Declare the data source
    default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
        instance_type_family="ecs.sn1ne")
    default_get_images = alicloud.ecs.get_images(name_regex="^ubuntu_[0-9]+_[0-9]+_x64*",
        most_recent=True,
        owners="system")
    default_network = alicloud.vpc.Network("default",
        vpc_name=name,
        cidr_block="192.168.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vswitch_name=name,
        vpc_id=default_network.id,
        cidr_block="192.168.192.0/24",
        zone_id=default.zones[0].id)
    default_security_group = alicloud.ecs.SecurityGroup("default",
        name=name,
        vpc_id=default_network.id)
    default_ecs_network_interface = alicloud.ecs.EcsNetworkInterface("default",
        network_interface_name=name,
        vswitch_id=default_switch.id,
        security_group_ids=[default_security_group.id])
    default_instance = []
    for range in [{"value": i} for i in range(0, 14)]:
        default_instance.append(alicloud.ecs.Instance(f"default-{range['value']}",
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            instance_name=name,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default.zones[0].id,
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id))
    ```


    :param str availability_zone: The zone where instance types are supported.
    :param int cpu_core_count: Filter the results to a specific number of cpu cores.
    :param int eni_amount: Filter the result whose network interface number is no more than `eni_amount`.
    :param int gpu_amount: The GPU amount of an instance type.
    :param str gpu_spec: The GPU spec of an instance type.
    :param str image_id: The ID of the image.
    :param str instance_charge_type: Filter the results by charge type. Valid values: `PrePaid` and `PostPaid`. Default to `PostPaid`.
    :param str instance_type: Instance specifications. For more information, see instance Specification Family, or you can call the describe instance types interface to get the latest specification table.
    :param str instance_type_family: Filter the results based on their family name. For example: 'ecs.n4'.
    :param bool is_outdated: If true, outdated instance types are included in the results. Default to false.
    :param str kubernetes_node_role: Filter the result which is used to create a kubernetes cluster
           and managed kubernetes cluster. Optional Values: `Master` and `Worker`.
    :param float memory_size: Filter the results to a specific memory size in GB.
    :param int minimum_eni_ipv6_address_quantity: The minimum number of IPv6 addresses per ENI. **Note:** If an instance type supports fewer IPv6 addresses per ENI than the specified value, information about the instance type is not queried.
    :param int minimum_eni_private_ip_address_quantity: The minimum expected IPv4 address upper limit of a single ENI when querying instance specifications. **Note:** If an instance type supports fewer IPv4 addresses per ENI than the specified value, information about the instance type is not queried.
    :param str network_type: Filter the results by network type. Valid values: `Classic` and `Vpc`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str sorted_by: Sort mode, valid values: `CPU`, `Memory`, `Price`.
    :param str spot_strategy: Filter the results by ECS spot type. Valid values: `NoSpot`, `SpotWithPriceLimit` and `SpotAsPriceGo`. Default to `NoSpot`.
    :param str system_disk_category: Filter the results by system disk category. Valid values: `cloud`, `ephemeral_ssd`, `cloud_essd`, `cloud_efficiency`, `cloud_ssd`, `cloud_essd_entry`, `cloud_auto`. 
           **NOTE**: Its default value `cloud_efficiency` has been removed from the version v1.150.0.
    """
    __args__ = dict()
    __args__['availabilityZone'] = availability_zone
    __args__['cpuCoreCount'] = cpu_core_count
    __args__['eniAmount'] = eni_amount
    __args__['gpuAmount'] = gpu_amount
    __args__['gpuSpec'] = gpu_spec
    __args__['imageId'] = image_id
    __args__['instanceChargeType'] = instance_charge_type
    __args__['instanceType'] = instance_type
    __args__['instanceTypeFamily'] = instance_type_family
    __args__['isOutdated'] = is_outdated
    __args__['kubernetesNodeRole'] = kubernetes_node_role
    __args__['memorySize'] = memory_size
    __args__['minimumEniIpv6AddressQuantity'] = minimum_eni_ipv6_address_quantity
    __args__['minimumEniPrivateIpAddressQuantity'] = minimum_eni_private_ip_address_quantity
    __args__['networkType'] = network_type
    __args__['outputFile'] = output_file
    __args__['sortedBy'] = sorted_by
    __args__['spotStrategy'] = spot_strategy
    __args__['systemDiskCategory'] = system_disk_category
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ecs/getInstanceTypes:getInstanceTypes', __args__, opts=opts, typ=GetInstanceTypesResult).value

    return AwaitableGetInstanceTypesResult(
        availability_zone=pulumi.get(__ret__, 'availability_zone'),
        cpu_core_count=pulumi.get(__ret__, 'cpu_core_count'),
        eni_amount=pulumi.get(__ret__, 'eni_amount'),
        gpu_amount=pulumi.get(__ret__, 'gpu_amount'),
        gpu_spec=pulumi.get(__ret__, 'gpu_spec'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        image_id=pulumi.get(__ret__, 'image_id'),
        instance_charge_type=pulumi.get(__ret__, 'instance_charge_type'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        instance_type_family=pulumi.get(__ret__, 'instance_type_family'),
        instance_types=pulumi.get(__ret__, 'instance_types'),
        is_outdated=pulumi.get(__ret__, 'is_outdated'),
        kubernetes_node_role=pulumi.get(__ret__, 'kubernetes_node_role'),
        memory_size=pulumi.get(__ret__, 'memory_size'),
        minimum_eni_ipv6_address_quantity=pulumi.get(__ret__, 'minimum_eni_ipv6_address_quantity'),
        minimum_eni_private_ip_address_quantity=pulumi.get(__ret__, 'minimum_eni_private_ip_address_quantity'),
        network_type=pulumi.get(__ret__, 'network_type'),
        output_file=pulumi.get(__ret__, 'output_file'),
        sorted_by=pulumi.get(__ret__, 'sorted_by'),
        spot_strategy=pulumi.get(__ret__, 'spot_strategy'),
        system_disk_category=pulumi.get(__ret__, 'system_disk_category'))
def get_instance_types_output(availability_zone: Optional[pulumi.Input[Optional[str]]] = None,
                              cpu_core_count: Optional[pulumi.Input[Optional[int]]] = None,
                              eni_amount: Optional[pulumi.Input[Optional[int]]] = None,
                              gpu_amount: Optional[pulumi.Input[Optional[int]]] = None,
                              gpu_spec: Optional[pulumi.Input[Optional[str]]] = None,
                              image_id: Optional[pulumi.Input[Optional[str]]] = None,
                              instance_charge_type: Optional[pulumi.Input[Optional[str]]] = None,
                              instance_type: Optional[pulumi.Input[Optional[str]]] = None,
                              instance_type_family: Optional[pulumi.Input[Optional[str]]] = None,
                              is_outdated: Optional[pulumi.Input[Optional[bool]]] = None,
                              kubernetes_node_role: Optional[pulumi.Input[Optional[str]]] = None,
                              memory_size: Optional[pulumi.Input[Optional[float]]] = None,
                              minimum_eni_ipv6_address_quantity: Optional[pulumi.Input[Optional[int]]] = None,
                              minimum_eni_private_ip_address_quantity: Optional[pulumi.Input[Optional[int]]] = None,
                              network_type: Optional[pulumi.Input[Optional[str]]] = None,
                              output_file: Optional[pulumi.Input[Optional[str]]] = None,
                              sorted_by: Optional[pulumi.Input[Optional[str]]] = None,
                              spot_strategy: Optional[pulumi.Input[Optional[str]]] = None,
                              system_disk_category: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstanceTypesResult]:
    """
    This data source provides the ECS instance types of Alibaba Cloud.

    > **NOTE:** By default, only the upgraded instance types are returned. If you want to get outdated instance types, you must set `is_outdated` to true.

    > **NOTE:** If one instance type is sold out, it will not be exported.

    > **NOTE:** Available since v1.0.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.get_zones(available_resource_creation="VSwitch")
    # Declare the data source
    default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
        instance_type_family="ecs.sn1ne")
    default_get_images = alicloud.ecs.get_images(name_regex="^ubuntu_[0-9]+_[0-9]+_x64*",
        most_recent=True,
        owners="system")
    default_network = alicloud.vpc.Network("default",
        vpc_name=name,
        cidr_block="192.168.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vswitch_name=name,
        vpc_id=default_network.id,
        cidr_block="192.168.192.0/24",
        zone_id=default.zones[0].id)
    default_security_group = alicloud.ecs.SecurityGroup("default",
        name=name,
        vpc_id=default_network.id)
    default_ecs_network_interface = alicloud.ecs.EcsNetworkInterface("default",
        network_interface_name=name,
        vswitch_id=default_switch.id,
        security_group_ids=[default_security_group.id])
    default_instance = []
    for range in [{"value": i} for i in range(0, 14)]:
        default_instance.append(alicloud.ecs.Instance(f"default-{range['value']}",
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            instance_name=name,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default.zones[0].id,
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id))
    ```


    :param str availability_zone: The zone where instance types are supported.
    :param int cpu_core_count: Filter the results to a specific number of cpu cores.
    :param int eni_amount: Filter the result whose network interface number is no more than `eni_amount`.
    :param int gpu_amount: The GPU amount of an instance type.
    :param str gpu_spec: The GPU spec of an instance type.
    :param str image_id: The ID of the image.
    :param str instance_charge_type: Filter the results by charge type. Valid values: `PrePaid` and `PostPaid`. Default to `PostPaid`.
    :param str instance_type: Instance specifications. For more information, see instance Specification Family, or you can call the describe instance types interface to get the latest specification table.
    :param str instance_type_family: Filter the results based on their family name. For example: 'ecs.n4'.
    :param bool is_outdated: If true, outdated instance types are included in the results. Default to false.
    :param str kubernetes_node_role: Filter the result which is used to create a kubernetes cluster
           and managed kubernetes cluster. Optional Values: `Master` and `Worker`.
    :param float memory_size: Filter the results to a specific memory size in GB.
    :param int minimum_eni_ipv6_address_quantity: The minimum number of IPv6 addresses per ENI. **Note:** If an instance type supports fewer IPv6 addresses per ENI than the specified value, information about the instance type is not queried.
    :param int minimum_eni_private_ip_address_quantity: The minimum expected IPv4 address upper limit of a single ENI when querying instance specifications. **Note:** If an instance type supports fewer IPv4 addresses per ENI than the specified value, information about the instance type is not queried.
    :param str network_type: Filter the results by network type. Valid values: `Classic` and `Vpc`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str sorted_by: Sort mode, valid values: `CPU`, `Memory`, `Price`.
    :param str spot_strategy: Filter the results by ECS spot type. Valid values: `NoSpot`, `SpotWithPriceLimit` and `SpotAsPriceGo`. Default to `NoSpot`.
    :param str system_disk_category: Filter the results by system disk category. Valid values: `cloud`, `ephemeral_ssd`, `cloud_essd`, `cloud_efficiency`, `cloud_ssd`, `cloud_essd_entry`, `cloud_auto`. 
           **NOTE**: Its default value `cloud_efficiency` has been removed from the version v1.150.0.
    """
    __args__ = dict()
    __args__['availabilityZone'] = availability_zone
    __args__['cpuCoreCount'] = cpu_core_count
    __args__['eniAmount'] = eni_amount
    __args__['gpuAmount'] = gpu_amount
    __args__['gpuSpec'] = gpu_spec
    __args__['imageId'] = image_id
    __args__['instanceChargeType'] = instance_charge_type
    __args__['instanceType'] = instance_type
    __args__['instanceTypeFamily'] = instance_type_family
    __args__['isOutdated'] = is_outdated
    __args__['kubernetesNodeRole'] = kubernetes_node_role
    __args__['memorySize'] = memory_size
    __args__['minimumEniIpv6AddressQuantity'] = minimum_eni_ipv6_address_quantity
    __args__['minimumEniPrivateIpAddressQuantity'] = minimum_eni_private_ip_address_quantity
    __args__['networkType'] = network_type
    __args__['outputFile'] = output_file
    __args__['sortedBy'] = sorted_by
    __args__['spotStrategy'] = spot_strategy
    __args__['systemDiskCategory'] = system_disk_category
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ecs/getInstanceTypes:getInstanceTypes', __args__, opts=opts, typ=GetInstanceTypesResult)
    return __ret__.apply(lambda __response__: GetInstanceTypesResult(
        availability_zone=pulumi.get(__response__, 'availability_zone'),
        cpu_core_count=pulumi.get(__response__, 'cpu_core_count'),
        eni_amount=pulumi.get(__response__, 'eni_amount'),
        gpu_amount=pulumi.get(__response__, 'gpu_amount'),
        gpu_spec=pulumi.get(__response__, 'gpu_spec'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        image_id=pulumi.get(__response__, 'image_id'),
        instance_charge_type=pulumi.get(__response__, 'instance_charge_type'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        instance_type_family=pulumi.get(__response__, 'instance_type_family'),
        instance_types=pulumi.get(__response__, 'instance_types'),
        is_outdated=pulumi.get(__response__, 'is_outdated'),
        kubernetes_node_role=pulumi.get(__response__, 'kubernetes_node_role'),
        memory_size=pulumi.get(__response__, 'memory_size'),
        minimum_eni_ipv6_address_quantity=pulumi.get(__response__, 'minimum_eni_ipv6_address_quantity'),
        minimum_eni_private_ip_address_quantity=pulumi.get(__response__, 'minimum_eni_private_ip_address_quantity'),
        network_type=pulumi.get(__response__, 'network_type'),
        output_file=pulumi.get(__response__, 'output_file'),
        sorted_by=pulumi.get(__response__, 'sorted_by'),
        spot_strategy=pulumi.get(__response__, 'spot_strategy'),
        system_disk_category=pulumi.get(__response__, 'system_disk_category')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBucketObjectsResult',
    'AwaitableGetBucketObjectsResult',
    'get_bucket_objects',
    'get_bucket_objects_output',
]

@pulumi.output_type
class GetBucketObjectsResult:
    """
    A collection of values returned by getBucketObjects.
    """
    def __init__(__self__, bucket_name=None, id=None, key_prefix=None, key_regex=None, objects=None, output_file=None):
        if bucket_name and not isinstance(bucket_name, str):
            raise TypeError("Expected argument 'bucket_name' to be a str")
        pulumi.set(__self__, "bucket_name", bucket_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_prefix and not isinstance(key_prefix, str):
            raise TypeError("Expected argument 'key_prefix' to be a str")
        pulumi.set(__self__, "key_prefix", key_prefix)
        if key_regex and not isinstance(key_regex, str):
            raise TypeError("Expected argument 'key_regex' to be a str")
        pulumi.set(__self__, "key_regex", key_regex)
        if objects and not isinstance(objects, list):
            raise TypeError("Expected argument 'objects' to be a list")
        pulumi.set(__self__, "objects", objects)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> str:
        return pulumi.get(self, "bucket_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyPrefix")
    def key_prefix(self) -> Optional[str]:
        return pulumi.get(self, "key_prefix")

    @property
    @pulumi.getter(name="keyRegex")
    def key_regex(self) -> Optional[str]:
        return pulumi.get(self, "key_regex")

    @property
    @pulumi.getter
    def objects(self) -> Sequence['outputs.GetBucketObjectsObjectResult']:
        """
        A list of bucket objects. Each element contains the following attributes:
        """
        return pulumi.get(self, "objects")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetBucketObjectsResult(GetBucketObjectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBucketObjectsResult(
            bucket_name=self.bucket_name,
            id=self.id,
            key_prefix=self.key_prefix,
            key_regex=self.key_regex,
            objects=self.objects,
            output_file=self.output_file)


def get_bucket_objects(bucket_name: Optional[str] = None,
                       key_prefix: Optional[str] = None,
                       key_regex: Optional[str] = None,
                       output_file: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBucketObjectsResult:
    """
    This data source provides the objects of an OSS bucket.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    bucket_objects_ds = alicloud.oss.get_bucket_objects(bucket_name="sample_bucket",
        key_regex="sample/sample_object.txt")
    pulumi.export("firstObjectKey", bucket_objects_ds.objects[0].key)
    ```


    :param str bucket_name: Name of the bucket that contains the objects to find.
    :param str key_prefix: Filter results by the given key prefix (such as "path/to/folder/logs-").
    :param str key_regex: A regex string to filter results by key.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['bucketName'] = bucket_name
    __args__['keyPrefix'] = key_prefix
    __args__['keyRegex'] = key_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:oss/getBucketObjects:getBucketObjects', __args__, opts=opts, typ=GetBucketObjectsResult).value

    return AwaitableGetBucketObjectsResult(
        bucket_name=pulumi.get(__ret__, 'bucket_name'),
        id=pulumi.get(__ret__, 'id'),
        key_prefix=pulumi.get(__ret__, 'key_prefix'),
        key_regex=pulumi.get(__ret__, 'key_regex'),
        objects=pulumi.get(__ret__, 'objects'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_bucket_objects_output(bucket_name: Optional[pulumi.Input[str]] = None,
                              key_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                              key_regex: Optional[pulumi.Input[Optional[str]]] = None,
                              output_file: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBucketObjectsResult]:
    """
    This data source provides the objects of an OSS bucket.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    bucket_objects_ds = alicloud.oss.get_bucket_objects(bucket_name="sample_bucket",
        key_regex="sample/sample_object.txt")
    pulumi.export("firstObjectKey", bucket_objects_ds.objects[0].key)
    ```


    :param str bucket_name: Name of the bucket that contains the objects to find.
    :param str key_prefix: Filter results by the given key prefix (such as "path/to/folder/logs-").
    :param str key_regex: A regex string to filter results by key.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['bucketName'] = bucket_name
    __args__['keyPrefix'] = key_prefix
    __args__['keyRegex'] = key_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:oss/getBucketObjects:getBucketObjects', __args__, opts=opts, typ=GetBucketObjectsResult)
    return __ret__.apply(lambda __response__: GetBucketObjectsResult(
        bucket_name=pulumi.get(__response__, 'bucket_name'),
        id=pulumi.get(__response__, 'id'),
        key_prefix=pulumi.get(__response__, 'key_prefix'),
        key_regex=pulumi.get(__response__, 'key_regex'),
        objects=pulumi.get(__response__, 'objects'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceMemberArgs', 'InstanceMember']

@pulumi.input_type
class InstanceMemberArgs:
    def __init__(__self__, *,
                 member_uid: pulumi.Input[str],
                 member_desc: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a InstanceMember resource.
        :param pulumi.Input[str] member_uid: The UID of the cloud firewall member account.
        :param pulumi.Input[str] member_desc: Remarks of cloud firewall member accounts.
        """
        pulumi.set(__self__, "member_uid", member_uid)
        if member_desc is not None:
            pulumi.set(__self__, "member_desc", member_desc)

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> pulumi.Input[str]:
        """
        The UID of the cloud firewall member account.
        """
        return pulumi.get(self, "member_uid")

    @member_uid.setter
    def member_uid(self, value: pulumi.Input[str]):
        pulumi.set(self, "member_uid", value)

    @property
    @pulumi.getter(name="memberDesc")
    def member_desc(self) -> Optional[pulumi.Input[str]]:
        """
        Remarks of cloud firewall member accounts.
        """
        return pulumi.get(self, "member_desc")

    @member_desc.setter
    def member_desc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_desc", value)


@pulumi.input_type
class _InstanceMemberState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[int]] = None,
                 member_desc: Optional[pulumi.Input[str]] = None,
                 member_display_name: Optional[pulumi.Input[str]] = None,
                 member_uid: Optional[pulumi.Input[str]] = None,
                 modify_time: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering InstanceMember resources.
        :param pulumi.Input[int] create_time: When the cloud firewall member account was added.> use second-level timestamp format.
        :param pulumi.Input[str] member_desc: Remarks of cloud firewall member accounts.
        :param pulumi.Input[str] member_display_name: The name of the cloud firewall member account.
        :param pulumi.Input[str] member_uid: The UID of the cloud firewall member account.
        :param pulumi.Input[int] modify_time: The last modification time of the cloud firewall member account.> use second-level timestamp format.
        :param pulumi.Input[str] status: The resource attribute field that represents the resource status.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if member_desc is not None:
            pulumi.set(__self__, "member_desc", member_desc)
        if member_display_name is not None:
            pulumi.set(__self__, "member_display_name", member_display_name)
        if member_uid is not None:
            pulumi.set(__self__, "member_uid", member_uid)
        if modify_time is not None:
            pulumi.set(__self__, "modify_time", modify_time)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[int]]:
        """
        When the cloud firewall member account was added.> use second-level timestamp format.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="memberDesc")
    def member_desc(self) -> Optional[pulumi.Input[str]]:
        """
        Remarks of cloud firewall member accounts.
        """
        return pulumi.get(self, "member_desc")

    @member_desc.setter
    def member_desc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_desc", value)

    @property
    @pulumi.getter(name="memberDisplayName")
    def member_display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the cloud firewall member account.
        """
        return pulumi.get(self, "member_display_name")

    @member_display_name.setter
    def member_display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_display_name", value)

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The UID of the cloud firewall member account.
        """
        return pulumi.get(self, "member_uid")

    @member_uid.setter
    def member_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_uid", value)

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> Optional[pulumi.Input[int]]:
        """
        The last modification time of the cloud firewall member account.> use second-level timestamp format.
        """
        return pulumi.get(self, "modify_time")

    @modify_time.setter
    def modify_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "modify_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The resource attribute field that represents the resource status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class InstanceMember(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 member_desc: Optional[pulumi.Input[str]] = None,
                 member_uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Firewall Instance Member resource.

        For information about Cloud Firewall Instance Member and how to use it, see [What is Instance Member](https://www.alibabacloud.com/help/en/server-load-balancer/latest/createloadbalancer).

        > **NOTE:** Available in v1.194.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "AliyunTerraform"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_account = alicloud.resourcemanager.Account("default", display_name=f"{name}-{default['result']}")
        default_instance_member = alicloud.cloudfirewall.InstanceMember("default",
            member_desc=f"{name}-{default['result']}",
            member_uid=default_account.id)
        ```

        ## Import

        Cloud Firewall Instance Member can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/instanceMember:InstanceMember example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] member_desc: Remarks of cloud firewall member accounts.
        :param pulumi.Input[str] member_uid: The UID of the cloud firewall member account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceMemberArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Firewall Instance Member resource.

        For information about Cloud Firewall Instance Member and how to use it, see [What is Instance Member](https://www.alibabacloud.com/help/en/server-load-balancer/latest/createloadbalancer).

        > **NOTE:** Available in v1.194.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "AliyunTerraform"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_account = alicloud.resourcemanager.Account("default", display_name=f"{name}-{default['result']}")
        default_instance_member = alicloud.cloudfirewall.InstanceMember("default",
            member_desc=f"{name}-{default['result']}",
            member_uid=default_account.id)
        ```

        ## Import

        Cloud Firewall Instance Member can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/instanceMember:InstanceMember example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceMemberArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceMemberArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 member_desc: Optional[pulumi.Input[str]] = None,
                 member_uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceMemberArgs.__new__(InstanceMemberArgs)

            __props__.__dict__["member_desc"] = member_desc
            if member_uid is None and not opts.urn:
                raise TypeError("Missing required property 'member_uid'")
            __props__.__dict__["member_uid"] = member_uid
            __props__.__dict__["create_time"] = None
            __props__.__dict__["member_display_name"] = None
            __props__.__dict__["modify_time"] = None
            __props__.__dict__["status"] = None
        super(InstanceMember, __self__).__init__(
            'alicloud:cloudfirewall/instanceMember:InstanceMember',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[int]] = None,
            member_desc: Optional[pulumi.Input[str]] = None,
            member_display_name: Optional[pulumi.Input[str]] = None,
            member_uid: Optional[pulumi.Input[str]] = None,
            modify_time: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'InstanceMember':
        """
        Get an existing InstanceMember resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] create_time: When the cloud firewall member account was added.> use second-level timestamp format.
        :param pulumi.Input[str] member_desc: Remarks of cloud firewall member accounts.
        :param pulumi.Input[str] member_display_name: The name of the cloud firewall member account.
        :param pulumi.Input[str] member_uid: The UID of the cloud firewall member account.
        :param pulumi.Input[int] modify_time: The last modification time of the cloud firewall member account.> use second-level timestamp format.
        :param pulumi.Input[str] status: The resource attribute field that represents the resource status.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceMemberState.__new__(_InstanceMemberState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["member_desc"] = member_desc
        __props__.__dict__["member_display_name"] = member_display_name
        __props__.__dict__["member_uid"] = member_uid
        __props__.__dict__["modify_time"] = modify_time
        __props__.__dict__["status"] = status
        return InstanceMember(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[int]:
        """
        When the cloud firewall member account was added.> use second-level timestamp format.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="memberDesc")
    def member_desc(self) -> pulumi.Output[Optional[str]]:
        """
        Remarks of cloud firewall member accounts.
        """
        return pulumi.get(self, "member_desc")

    @property
    @pulumi.getter(name="memberDisplayName")
    def member_display_name(self) -> pulumi.Output[str]:
        """
        The name of the cloud firewall member account.
        """
        return pulumi.get(self, "member_display_name")

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> pulumi.Output[str]:
        """
        The UID of the cloud firewall member account.
        """
        return pulumi.get(self, "member_uid")

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> pulumi.Output[int]:
        """
        The last modification time of the cloud firewall member account.> use second-level timestamp format.
        """
        return pulumi.get(self, "modify_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The resource attribute field that represents the resource status.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IndustrialPidProjectArgs', 'IndustrialPidProject']

@pulumi.input_type
class IndustrialPidProjectArgs:
    def __init__(__self__, *,
                 pid_organization_id: pulumi.Input[str],
                 pid_project_name: pulumi.Input[str],
                 pid_project_desc: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a IndustrialPidProject resource.
        :param pulumi.Input[str] pid_organization_id: The ID of Pid Organization.
        :param pulumi.Input[str] pid_project_name: The name of Pid Project.
        :param pulumi.Input[str] pid_project_desc: The description of Pid Project.
        """
        pulumi.set(__self__, "pid_organization_id", pid_organization_id)
        pulumi.set(__self__, "pid_project_name", pid_project_name)
        if pid_project_desc is not None:
            pulumi.set(__self__, "pid_project_desc", pid_project_desc)

    @property
    @pulumi.getter(name="pidOrganizationId")
    def pid_organization_id(self) -> pulumi.Input[str]:
        """
        The ID of Pid Organization.
        """
        return pulumi.get(self, "pid_organization_id")

    @pid_organization_id.setter
    def pid_organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "pid_organization_id", value)

    @property
    @pulumi.getter(name="pidProjectName")
    def pid_project_name(self) -> pulumi.Input[str]:
        """
        The name of Pid Project.
        """
        return pulumi.get(self, "pid_project_name")

    @pid_project_name.setter
    def pid_project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "pid_project_name", value)

    @property
    @pulumi.getter(name="pidProjectDesc")
    def pid_project_desc(self) -> Optional[pulumi.Input[str]]:
        """
        The description of Pid Project.
        """
        return pulumi.get(self, "pid_project_desc")

    @pid_project_desc.setter
    def pid_project_desc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pid_project_desc", value)


@pulumi.input_type
class _IndustrialPidProjectState:
    def __init__(__self__, *,
                 pid_organization_id: Optional[pulumi.Input[str]] = None,
                 pid_project_desc: Optional[pulumi.Input[str]] = None,
                 pid_project_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IndustrialPidProject resources.
        :param pulumi.Input[str] pid_organization_id: The ID of Pid Organization.
        :param pulumi.Input[str] pid_project_desc: The description of Pid Project.
        :param pulumi.Input[str] pid_project_name: The name of Pid Project.
        """
        if pid_organization_id is not None:
            pulumi.set(__self__, "pid_organization_id", pid_organization_id)
        if pid_project_desc is not None:
            pulumi.set(__self__, "pid_project_desc", pid_project_desc)
        if pid_project_name is not None:
            pulumi.set(__self__, "pid_project_name", pid_project_name)

    @property
    @pulumi.getter(name="pidOrganizationId")
    def pid_organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of Pid Organization.
        """
        return pulumi.get(self, "pid_organization_id")

    @pid_organization_id.setter
    def pid_organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pid_organization_id", value)

    @property
    @pulumi.getter(name="pidProjectDesc")
    def pid_project_desc(self) -> Optional[pulumi.Input[str]]:
        """
        The description of Pid Project.
        """
        return pulumi.get(self, "pid_project_desc")

    @pid_project_desc.setter
    def pid_project_desc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pid_project_desc", value)

    @property
    @pulumi.getter(name="pidProjectName")
    def pid_project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of Pid Project.
        """
        return pulumi.get(self, "pid_project_name")

    @pid_project_name.setter
    def pid_project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pid_project_name", value)


class IndustrialPidProject(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 pid_organization_id: Optional[pulumi.Input[str]] = None,
                 pid_project_desc: Optional[pulumi.Input[str]] = None,
                 pid_project_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Brain Industrial Pid Project resource.

        > **NOTE:** Available since v1.113.0.

        > **DEPRECATED:**  This resource has been deprecated from version `1.222.0`.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.brain.IndustrialPidProject("example",
            pid_organization_id="3e74e684-cbb5-xxxx",
            pid_project_name="tf-testAcc")
        ```

        ## Import

        Brain Industrial Pid Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:brain/industrialPidProject:IndustrialPidProject example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] pid_organization_id: The ID of Pid Organization.
        :param pulumi.Input[str] pid_project_desc: The description of Pid Project.
        :param pulumi.Input[str] pid_project_name: The name of Pid Project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IndustrialPidProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Brain Industrial Pid Project resource.

        > **NOTE:** Available since v1.113.0.

        > **DEPRECATED:**  This resource has been deprecated from version `1.222.0`.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.brain.IndustrialPidProject("example",
            pid_organization_id="3e74e684-cbb5-xxxx",
            pid_project_name="tf-testAcc")
        ```

        ## Import

        Brain Industrial Pid Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:brain/industrialPidProject:IndustrialPidProject example <id>
        ```

        :param str resource_name: The name of the resource.
        :param IndustrialPidProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IndustrialPidProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 pid_organization_id: Optional[pulumi.Input[str]] = None,
                 pid_project_desc: Optional[pulumi.Input[str]] = None,
                 pid_project_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IndustrialPidProjectArgs.__new__(IndustrialPidProjectArgs)

            if pid_organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'pid_organization_id'")
            __props__.__dict__["pid_organization_id"] = pid_organization_id
            __props__.__dict__["pid_project_desc"] = pid_project_desc
            if pid_project_name is None and not opts.urn:
                raise TypeError("Missing required property 'pid_project_name'")
            __props__.__dict__["pid_project_name"] = pid_project_name
        super(IndustrialPidProject, __self__).__init__(
            'alicloud:brain/industrialPidProject:IndustrialPidProject',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            pid_organization_id: Optional[pulumi.Input[str]] = None,
            pid_project_desc: Optional[pulumi.Input[str]] = None,
            pid_project_name: Optional[pulumi.Input[str]] = None) -> 'IndustrialPidProject':
        """
        Get an existing IndustrialPidProject resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] pid_organization_id: The ID of Pid Organization.
        :param pulumi.Input[str] pid_project_desc: The description of Pid Project.
        :param pulumi.Input[str] pid_project_name: The name of Pid Project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IndustrialPidProjectState.__new__(_IndustrialPidProjectState)

        __props__.__dict__["pid_organization_id"] = pid_organization_id
        __props__.__dict__["pid_project_desc"] = pid_project_desc
        __props__.__dict__["pid_project_name"] = pid_project_name
        return IndustrialPidProject(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="pidOrganizationId")
    def pid_organization_id(self) -> pulumi.Output[str]:
        """
        The ID of Pid Organization.
        """
        return pulumi.get(self, "pid_organization_id")

    @property
    @pulumi.getter(name="pidProjectDesc")
    def pid_project_desc(self) -> pulumi.Output[Optional[str]]:
        """
        The description of Pid Project.
        """
        return pulumi.get(self, "pid_project_desc")

    @property
    @pulumi.getter(name="pidProjectName")
    def pid_project_name(self) -> pulumi.Output[str]:
        """
        The name of Pid Project.
        """
        return pulumi.get(self, "pid_project_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProductArgs', 'Product']

@pulumi.input_type
class ProductArgs:
    def __init__(__self__, *,
                 product_name: pulumi.Input[str],
                 product_type: pulumi.Input[str],
                 provider_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Product resource.
        :param pulumi.Input[str] product_name: The name of the product
        :param pulumi.Input[str] product_type: The type of the product
        :param pulumi.Input[str] provider_name: The provider name of the product
        :param pulumi.Input[str] description: The description of the product
        """
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_type", product_type)
        pulumi.set(__self__, "provider_name", provider_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> pulumi.Input[str]:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @product_name.setter
    def product_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_name", value)

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> pulumi.Input[str]:
        """
        The type of the product
        """
        return pulumi.get(self, "product_type")

    @product_type.setter
    def product_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_type", value)

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> pulumi.Input[str]:
        """
        The provider name of the product
        """
        return pulumi.get(self, "provider_name")

    @provider_name.setter
    def provider_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "provider_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the product
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ProductState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 product_name: Optional[pulumi.Input[str]] = None,
                 product_type: Optional[pulumi.Input[str]] = None,
                 provider_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Product resources.
        :param pulumi.Input[str] create_time: The creation time of the product
        :param pulumi.Input[str] description: The description of the product
        :param pulumi.Input[str] product_name: The name of the product
        :param pulumi.Input[str] product_type: The type of the product
        :param pulumi.Input[str] provider_name: The provider name of the product
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if product_name is not None:
            pulumi.set(__self__, "product_name", product_name)
        if product_type is not None:
            pulumi.set(__self__, "product_type", product_type)
        if provider_name is not None:
            pulumi.set(__self__, "provider_name", provider_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the product
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the product
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @product_name.setter
    def product_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_name", value)

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the product
        """
        return pulumi.get(self, "product_type")

    @product_type.setter
    def product_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_type", value)

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> Optional[pulumi.Input[str]]:
        """
        The provider name of the product
        """
        return pulumi.get(self, "provider_name")

    @provider_name.setter
    def provider_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provider_name", value)


class Product(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 product_name: Optional[pulumi.Input[str]] = None,
                 product_type: Optional[pulumi.Input[str]] = None,
                 provider_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Service Catalog Product resource.

        Service catalog product, IaC template encapsulation concept.

        For information about Service Catalog Product and how to use it, see [What is Product](https://www.alibabacloud.com/help/en/service-catalog/developer-reference/api-servicecatalog-2021-09-01-createproduct).

        > **NOTE:** Available since v1.230.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.servicecatalog.Product("default",
            provider_name=name,
            description="desc",
            product_name=name,
            product_type="Ros")
        ```

        ## Import

        Service Catalog Product can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:servicecatalog/product:Product example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the product
        :param pulumi.Input[str] product_name: The name of the product
        :param pulumi.Input[str] product_type: The type of the product
        :param pulumi.Input[str] provider_name: The provider name of the product
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProductArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Service Catalog Product resource.

        Service catalog product, IaC template encapsulation concept.

        For information about Service Catalog Product and how to use it, see [What is Product](https://www.alibabacloud.com/help/en/service-catalog/developer-reference/api-servicecatalog-2021-09-01-createproduct).

        > **NOTE:** Available since v1.230.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.servicecatalog.Product("default",
            provider_name=name,
            description="desc",
            product_name=name,
            product_type="Ros")
        ```

        ## Import

        Service Catalog Product can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:servicecatalog/product:Product example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ProductArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProductArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 product_name: Optional[pulumi.Input[str]] = None,
                 product_type: Optional[pulumi.Input[str]] = None,
                 provider_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProductArgs.__new__(ProductArgs)

            __props__.__dict__["description"] = description
            if product_name is None and not opts.urn:
                raise TypeError("Missing required property 'product_name'")
            __props__.__dict__["product_name"] = product_name
            if product_type is None and not opts.urn:
                raise TypeError("Missing required property 'product_type'")
            __props__.__dict__["product_type"] = product_type
            if provider_name is None and not opts.urn:
                raise TypeError("Missing required property 'provider_name'")
            __props__.__dict__["provider_name"] = provider_name
            __props__.__dict__["create_time"] = None
        super(Product, __self__).__init__(
            'alicloud:servicecatalog/product:Product',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            product_name: Optional[pulumi.Input[str]] = None,
            product_type: Optional[pulumi.Input[str]] = None,
            provider_name: Optional[pulumi.Input[str]] = None) -> 'Product':
        """
        Get an existing Product resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the product
        :param pulumi.Input[str] description: The description of the product
        :param pulumi.Input[str] product_name: The name of the product
        :param pulumi.Input[str] product_type: The type of the product
        :param pulumi.Input[str] provider_name: The provider name of the product
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProductState.__new__(_ProductState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["product_name"] = product_name
        __props__.__dict__["product_type"] = product_type
        __props__.__dict__["provider_name"] = provider_name
        return Product(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the product
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the product
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> pulumi.Output[str]:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> pulumi.Output[str]:
        """
        The type of the product
        """
        return pulumi.get(self, "product_type")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> pulumi.Output[str]:
        """
        The provider name of the product
        """
        return pulumi.get(self, "provider_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SolutionInstanceArgs', 'SolutionInstance']

@pulumi.input_type
class SolutionInstanceArgs:
    def __init__(__self__, *,
                 solution_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 solution_instance_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SolutionInstance resource.
        :param pulumi.Input[str] solution_id: Solution ID.
        :param pulumi.Input[str] description: Solution Instance Description.
        :param pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]] parameters: Solution Instance Creation Parameters. See `parameters` below.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] solution_instance_name: Solution Instance Name.
        """
        pulumi.set(__self__, "solution_id", solution_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if solution_instance_name is not None:
            pulumi.set(__self__, "solution_instance_name", solution_instance_name)

    @property
    @pulumi.getter(name="solutionId")
    def solution_id(self) -> pulumi.Input[str]:
        """
        Solution ID.
        """
        return pulumi.get(self, "solution_id")

    @solution_id.setter
    def solution_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "solution_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Solution Instance Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]]]:
        """
        Solution Instance Creation Parameters. See `parameters` below.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="solutionInstanceName")
    def solution_instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        Solution Instance Name.
        """
        return pulumi.get(self, "solution_instance_name")

    @solution_instance_name.setter
    def solution_instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "solution_instance_name", value)


@pulumi.input_type
class _SolutionInstanceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 solution_id: Optional[pulumi.Input[str]] = None,
                 solution_instance_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SolutionInstance resources.
        :param pulumi.Input[str] create_time: Solution Instance Creation Time.
        :param pulumi.Input[str] description: Solution Instance Description.
        :param pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]] parameters: Solution Instance Creation Parameters. See `parameters` below.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] solution_id: Solution ID.
        :param pulumi.Input[str] solution_instance_name: Solution Instance Name.
        :param pulumi.Input[str] status: The status of the resource.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if solution_id is not None:
            pulumi.set(__self__, "solution_id", solution_id)
        if solution_instance_name is not None:
            pulumi.set(__self__, "solution_instance_name", solution_instance_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Solution Instance Creation Time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Solution Instance Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]]]:
        """
        Solution Instance Creation Parameters. See `parameters` below.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SolutionInstanceParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="solutionId")
    def solution_id(self) -> Optional[pulumi.Input[str]]:
        """
        Solution ID.
        """
        return pulumi.get(self, "solution_id")

    @solution_id.setter
    def solution_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "solution_id", value)

    @property
    @pulumi.getter(name="solutionInstanceName")
    def solution_instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        Solution Instance Name.
        """
        return pulumi.get(self, "solution_instance_name")

    @solution_instance_name.setter
    def solution_instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "solution_instance_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class SolutionInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SolutionInstanceParameterArgs', 'SolutionInstanceParameterArgsDict']]]]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 solution_id: Optional[pulumi.Input[str]] = None,
                 solution_instance_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a EBS Solution Instance resource.

        For information about EBS Solution Instance and how to use it, see [What is Solution Instance](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.216.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        zone_id = config.get("zoneId")
        if zone_id is None:
            zone_id = "cn-shanghai-l"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-shanghai"
        default = alicloud.resourcemanager.get_resource_groups()
        default_solution_instance = alicloud.ebs.SolutionInstance("default",
            solution_instance_name=name,
            resource_group_id=default.ids[0],
            description="description",
            solution_id="mysql",
            parameters=[
                {
                    "parameter_key": "zoneId",
                    "parameter_value": zone_id,
                },
                {
                    "parameter_key": "ecsType",
                    "parameter_value": "ecs.c6.large",
                },
                {
                    "parameter_key": "ecsImageId",
                    "parameter_value": "CentOS_7",
                },
                {
                    "parameter_key": "internetMaxBandwidthOut",
                    "parameter_value": "100",
                },
                {
                    "parameter_key": "internetChargeType",
                    "parameter_value": "PayByTraffic",
                },
                {
                    "parameter_key": "ecsPassword",
                    "parameter_value": "Ebs12345",
                },
                {
                    "parameter_key": "sysDiskType",
                    "parameter_value": "cloud_essd",
                },
                {
                    "parameter_key": "sysDiskPerformance",
                    "parameter_value": "PL0",
                },
                {
                    "parameter_key": "sysDiskSize",
                    "parameter_value": "40",
                },
                {
                    "parameter_key": "dataDiskType",
                    "parameter_value": "cloud_essd",
                },
                {
                    "parameter_key": "dataDiskPerformance",
                    "parameter_value": "PL0",
                },
                {
                    "parameter_key": "dataDiskSize",
                    "parameter_value": "40",
                },
                {
                    "parameter_key": "mysqlVersion",
                    "parameter_value": "MySQL80",
                },
                {
                    "parameter_key": "mysqlUser",
                    "parameter_value": "root",
                },
                {
                    "parameter_key": "mysqlPassword",
                    "parameter_value": "Ebs12345",
                },
            ])
        ```

        ## Import

        EBS Solution Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ebs/solutionInstance:SolutionInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Solution Instance Description.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SolutionInstanceParameterArgs', 'SolutionInstanceParameterArgsDict']]]] parameters: Solution Instance Creation Parameters. See `parameters` below.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] solution_id: Solution ID.
        :param pulumi.Input[str] solution_instance_name: Solution Instance Name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SolutionInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a EBS Solution Instance resource.

        For information about EBS Solution Instance and how to use it, see [What is Solution Instance](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.216.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        zone_id = config.get("zoneId")
        if zone_id is None:
            zone_id = "cn-shanghai-l"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-shanghai"
        default = alicloud.resourcemanager.get_resource_groups()
        default_solution_instance = alicloud.ebs.SolutionInstance("default",
            solution_instance_name=name,
            resource_group_id=default.ids[0],
            description="description",
            solution_id="mysql",
            parameters=[
                {
                    "parameter_key": "zoneId",
                    "parameter_value": zone_id,
                },
                {
                    "parameter_key": "ecsType",
                    "parameter_value": "ecs.c6.large",
                },
                {
                    "parameter_key": "ecsImageId",
                    "parameter_value": "CentOS_7",
                },
                {
                    "parameter_key": "internetMaxBandwidthOut",
                    "parameter_value": "100",
                },
                {
                    "parameter_key": "internetChargeType",
                    "parameter_value": "PayByTraffic",
                },
                {
                    "parameter_key": "ecsPassword",
                    "parameter_value": "Ebs12345",
                },
                {
                    "parameter_key": "sysDiskType",
                    "parameter_value": "cloud_essd",
                },
                {
                    "parameter_key": "sysDiskPerformance",
                    "parameter_value": "PL0",
                },
                {
                    "parameter_key": "sysDiskSize",
                    "parameter_value": "40",
                },
                {
                    "parameter_key": "dataDiskType",
                    "parameter_value": "cloud_essd",
                },
                {
                    "parameter_key": "dataDiskPerformance",
                    "parameter_value": "PL0",
                },
                {
                    "parameter_key": "dataDiskSize",
                    "parameter_value": "40",
                },
                {
                    "parameter_key": "mysqlVersion",
                    "parameter_value": "MySQL80",
                },
                {
                    "parameter_key": "mysqlUser",
                    "parameter_value": "root",
                },
                {
                    "parameter_key": "mysqlPassword",
                    "parameter_value": "Ebs12345",
                },
            ])
        ```

        ## Import

        EBS Solution Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ebs/solutionInstance:SolutionInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param SolutionInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SolutionInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SolutionInstanceParameterArgs', 'SolutionInstanceParameterArgsDict']]]]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 solution_id: Optional[pulumi.Input[str]] = None,
                 solution_instance_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SolutionInstanceArgs.__new__(SolutionInstanceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["resource_group_id"] = resource_group_id
            if solution_id is None and not opts.urn:
                raise TypeError("Missing required property 'solution_id'")
            __props__.__dict__["solution_id"] = solution_id
            __props__.__dict__["solution_instance_name"] = solution_instance_name
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(SolutionInstance, __self__).__init__(
            'alicloud:ebs/solutionInstance:SolutionInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SolutionInstanceParameterArgs', 'SolutionInstanceParameterArgsDict']]]]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            solution_id: Optional[pulumi.Input[str]] = None,
            solution_instance_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'SolutionInstance':
        """
        Get an existing SolutionInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: Solution Instance Creation Time.
        :param pulumi.Input[str] description: Solution Instance Description.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SolutionInstanceParameterArgs', 'SolutionInstanceParameterArgsDict']]]] parameters: Solution Instance Creation Parameters. See `parameters` below.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] solution_id: Solution ID.
        :param pulumi.Input[str] solution_instance_name: Solution Instance Name.
        :param pulumi.Input[str] status: The status of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SolutionInstanceState.__new__(_SolutionInstanceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["solution_id"] = solution_id
        __props__.__dict__["solution_instance_name"] = solution_instance_name
        __props__.__dict__["status"] = status
        return SolutionInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Solution Instance Creation Time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Solution Instance Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[Sequence['outputs.SolutionInstanceParameter']]]:
        """
        Solution Instance Creation Parameters. See `parameters` below.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="solutionId")
    def solution_id(self) -> pulumi.Output[str]:
        """
        Solution ID.
        """
        return pulumi.get(self, "solution_id")

    @property
    @pulumi.getter(name="solutionInstanceName")
    def solution_instance_name(self) -> pulumi.Output[str]:
        """
        Solution Instance Name.
        """
        return pulumi.get(self, "solution_instance_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AlertContactGroupArgs', 'AlertContactGroup']

@pulumi.input_type
class AlertContactGroupArgs:
    def __init__(__self__, *,
                 alert_contact_group_name: pulumi.Input[str],
                 contact_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a AlertContactGroup resource.
        :param pulumi.Input[str] alert_contact_group_name: The name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_ids: The list id of alert contact.
        """
        pulumi.set(__self__, "alert_contact_group_name", alert_contact_group_name)
        if contact_ids is not None:
            pulumi.set(__self__, "contact_ids", contact_ids)

    @property
    @pulumi.getter(name="alertContactGroupName")
    def alert_contact_group_name(self) -> pulumi.Input[str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "alert_contact_group_name")

    @alert_contact_group_name.setter
    def alert_contact_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "alert_contact_group_name", value)

    @property
    @pulumi.getter(name="contactIds")
    def contact_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list id of alert contact.
        """
        return pulumi.get(self, "contact_ids")

    @contact_ids.setter
    def contact_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "contact_ids", value)


@pulumi.input_type
class _AlertContactGroupState:
    def __init__(__self__, *,
                 alert_contact_group_name: Optional[pulumi.Input[str]] = None,
                 contact_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering AlertContactGroup resources.
        :param pulumi.Input[str] alert_contact_group_name: The name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_ids: The list id of alert contact.
        """
        if alert_contact_group_name is not None:
            pulumi.set(__self__, "alert_contact_group_name", alert_contact_group_name)
        if contact_ids is not None:
            pulumi.set(__self__, "contact_ids", contact_ids)

    @property
    @pulumi.getter(name="alertContactGroupName")
    def alert_contact_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "alert_contact_group_name")

    @alert_contact_group_name.setter
    def alert_contact_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alert_contact_group_name", value)

    @property
    @pulumi.getter(name="contactIds")
    def contact_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list id of alert contact.
        """
        return pulumi.get(self, "contact_ids")

    @contact_ids.setter
    def contact_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "contact_ids", value)


class AlertContactGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_contact_group_name: Optional[pulumi.Input[str]] = None,
                 contact_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a Application Real-Time Monitoring Service (ARMS) Alert Contact Group resource.

        For information about Application Real-Time Monitoring Service (ARMS) Alert Contact Group and how to use it, see [What is Alert Contact Group](https://www.alibabacloud.com/help/en/doc-detail/130677.htm).

        > **NOTE:** Available since v1.131.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.arms.AlertContact("example",
            alert_contact_name="example_value",
            ding_robot_webhook_url="https://oapi.dingtalk.com/robot/send?access_token=91f2f6****",
            email="someone@example.com",
            phone_num="1381111****")
        example_alert_contact_group = alicloud.arms.AlertContactGroup("example",
            alert_contact_group_name="example_value",
            contact_ids=[example.id])
        ```

        ## Import

        Application Real-Time Monitoring Service (ARMS) Alert Contact Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:arms/alertContactGroup:AlertContactGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alert_contact_group_name: The name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_ids: The list id of alert contact.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertContactGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Application Real-Time Monitoring Service (ARMS) Alert Contact Group resource.

        For information about Application Real-Time Monitoring Service (ARMS) Alert Contact Group and how to use it, see [What is Alert Contact Group](https://www.alibabacloud.com/help/en/doc-detail/130677.htm).

        > **NOTE:** Available since v1.131.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.arms.AlertContact("example",
            alert_contact_name="example_value",
            ding_robot_webhook_url="https://oapi.dingtalk.com/robot/send?access_token=91f2f6****",
            email="someone@example.com",
            phone_num="1381111****")
        example_alert_contact_group = alicloud.arms.AlertContactGroup("example",
            alert_contact_group_name="example_value",
            contact_ids=[example.id])
        ```

        ## Import

        Application Real-Time Monitoring Service (ARMS) Alert Contact Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:arms/alertContactGroup:AlertContactGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AlertContactGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertContactGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_contact_group_name: Optional[pulumi.Input[str]] = None,
                 contact_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertContactGroupArgs.__new__(AlertContactGroupArgs)

            if alert_contact_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'alert_contact_group_name'")
            __props__.__dict__["alert_contact_group_name"] = alert_contact_group_name
            __props__.__dict__["contact_ids"] = contact_ids
        super(AlertContactGroup, __self__).__init__(
            'alicloud:arms/alertContactGroup:AlertContactGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alert_contact_group_name: Optional[pulumi.Input[str]] = None,
            contact_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'AlertContactGroup':
        """
        Get an existing AlertContactGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alert_contact_group_name: The name of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_ids: The list id of alert contact.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertContactGroupState.__new__(_AlertContactGroupState)

        __props__.__dict__["alert_contact_group_name"] = alert_contact_group_name
        __props__.__dict__["contact_ids"] = contact_ids
        return AlertContactGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alertContactGroupName")
    def alert_contact_group_name(self) -> pulumi.Output[str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "alert_contact_group_name")

    @property
    @pulumi.getter(name="contactIds")
    def contact_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list id of alert contact.
        """
        return pulumi.get(self, "contact_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 domain_name: pulumi.Input[str],
                 sources: pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]],
                 biz_name: Optional[pulumi.Input[str]] = None,
                 cert_infos: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]]] = None,
                 check_url: Optional[pulumi.Input[str]] = None,
                 force_set: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Domain resource.
        :param pulumi.Input[str] domain_name: The name of domain.
        :param pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]] sources: the Origin Server Information. See the following `Block sources`.
        :param pulumi.Input[str] biz_name: Attribute perm has been deprecated and suggest removing it from your template.
        :param pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]] cert_infos: Certificate Information. See the following `Block cert_infos`.
        :param pulumi.Input[str] check_url: The health check url.
        :param pulumi.Input[str] force_set: Whether to set certificate forcibly.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `offline`, `online`.
        """
        pulumi.set(__self__, "domain_name", domain_name)
        pulumi.set(__self__, "sources", sources)
        if biz_name is not None:
            warnings.warn("""Attribute biz_name has been deprecated and suggest removing it from your template.""", DeprecationWarning)
            pulumi.log.warn("""biz_name is deprecated: Attribute biz_name has been deprecated and suggest removing it from your template.""")
        if biz_name is not None:
            pulumi.set(__self__, "biz_name", biz_name)
        if cert_infos is not None:
            pulumi.set(__self__, "cert_infos", cert_infos)
        if check_url is not None:
            pulumi.set(__self__, "check_url", check_url)
        if force_set is not None:
            pulumi.set(__self__, "force_set", force_set)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Input[str]:
        """
        The name of domain.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter
    def sources(self) -> pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]]:
        """
        the Origin Server Information. See the following `Block sources`.
        """
        return pulumi.get(self, "sources")

    @sources.setter
    def sources(self, value: pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]]):
        pulumi.set(self, "sources", value)

    @property
    @pulumi.getter(name="bizName")
    @_utilities.deprecated("""Attribute biz_name has been deprecated and suggest removing it from your template.""")
    def biz_name(self) -> Optional[pulumi.Input[str]]:
        """
        Attribute perm has been deprecated and suggest removing it from your template.
        """
        return pulumi.get(self, "biz_name")

    @biz_name.setter
    def biz_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_name", value)

    @property
    @pulumi.getter(name="certInfos")
    def cert_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]]]:
        """
        Certificate Information. See the following `Block cert_infos`.
        """
        return pulumi.get(self, "cert_infos")

    @cert_infos.setter
    def cert_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]]]):
        pulumi.set(self, "cert_infos", value)

    @property
    @pulumi.getter(name="checkUrl")
    def check_url(self) -> Optional[pulumi.Input[str]]:
        """
        The health check url.
        """
        return pulumi.get(self, "check_url")

    @check_url.setter
    def check_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "check_url", value)

    @property
    @pulumi.getter(name="forceSet")
    def force_set(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to set certificate forcibly.
        """
        return pulumi.get(self, "force_set")

    @force_set.setter
    def force_set(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "force_set", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group id.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values: `offline`, `online`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 cert_infos: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]]] = None,
                 check_url: Optional[pulumi.Input[str]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 force_set: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        :param pulumi.Input[str] biz_name: Attribute perm has been deprecated and suggest removing it from your template.
        :param pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]] cert_infos: Certificate Information. See the following `Block cert_infos`.
        :param pulumi.Input[str] check_url: The health check url.
        :param pulumi.Input[str] domain_name: The name of domain.
        :param pulumi.Input[str] force_set: Whether to set certificate forcibly.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]] sources: the Origin Server Information. See the following `Block sources`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `offline`, `online`.
        """
        if biz_name is not None:
            warnings.warn("""Attribute biz_name has been deprecated and suggest removing it from your template.""", DeprecationWarning)
            pulumi.log.warn("""biz_name is deprecated: Attribute biz_name has been deprecated and suggest removing it from your template.""")
        if biz_name is not None:
            pulumi.set(__self__, "biz_name", biz_name)
        if cert_infos is not None:
            pulumi.set(__self__, "cert_infos", cert_infos)
        if check_url is not None:
            pulumi.set(__self__, "check_url", check_url)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if force_set is not None:
            pulumi.set(__self__, "force_set", force_set)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if sources is not None:
            pulumi.set(__self__, "sources", sources)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="bizName")
    @_utilities.deprecated("""Attribute biz_name has been deprecated and suggest removing it from your template.""")
    def biz_name(self) -> Optional[pulumi.Input[str]]:
        """
        Attribute perm has been deprecated and suggest removing it from your template.
        """
        return pulumi.get(self, "biz_name")

    @biz_name.setter
    def biz_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_name", value)

    @property
    @pulumi.getter(name="certInfos")
    def cert_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]]]:
        """
        Certificate Information. See the following `Block cert_infos`.
        """
        return pulumi.get(self, "cert_infos")

    @cert_infos.setter
    def cert_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCertInfoArgs']]]]):
        pulumi.set(self, "cert_infos", value)

    @property
    @pulumi.getter(name="checkUrl")
    def check_url(self) -> Optional[pulumi.Input[str]]:
        """
        The health check url.
        """
        return pulumi.get(self, "check_url")

    @check_url.setter
    def check_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "check_url", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of domain.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="forceSet")
    def force_set(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to set certificate forcibly.
        """
        return pulumi.get(self, "force_set")

    @force_set.setter
    def force_set(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "force_set", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group id.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]]]:
        """
        the Origin Server Information. See the following `Block sources`.
        """
        return pulumi.get(self, "sources")

    @sources.setter
    def sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainSourceArgs']]]]):
        pulumi.set(self, "sources", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values: `offline`, `online`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 cert_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainCertInfoArgs', 'DomainCertInfoArgsDict']]]]] = None,
                 check_url: Optional[pulumi.Input[str]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 force_set: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainSourceArgs', 'DomainSourceArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a SCDN Domain resource.

        For information about SCDN Domain and how to use it, see [What is Domain](https://help.aliyun.com/document_detail/63672.html).

        > **NOTE:** Available in v1.131.0+.

        > **NOTE:** Alibaba Cloud SCDN has stopped new customer purchases from January 26, 2023, and you can choose to buy Alibaba Cloud DCDN products with more comprehensive acceleration and protection capabilities. If you are already a SCDN customer, you can submit a work order at any time to apply for a smooth migration to Alibaba Cloud DCDN products. In the future, we will provide better acceleration and security protection services in Alibaba Cloud DCDN, thank you for your understanding and cooperation.

        > **DEPRECATED:**  This resource has been [deprecated](https://www.aliyun.com/product/scdn) from version `1.219.0`.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.scdn.Domain("example",
            domain_name="my-Domain",
            sources=[{
                "content": "xxx.aliyuncs.com",
                "enabled": "online",
                "port": 80,
                "priority": "20",
                "type": "oss",
            }])
        ```

        ## Import

        SCDN Domain can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:scdn/domain:Domain example <domain_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] biz_name: Attribute perm has been deprecated and suggest removing it from your template.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainCertInfoArgs', 'DomainCertInfoArgsDict']]]] cert_infos: Certificate Information. See the following `Block cert_infos`.
        :param pulumi.Input[str] check_url: The health check url.
        :param pulumi.Input[str] domain_name: The name of domain.
        :param pulumi.Input[str] force_set: Whether to set certificate forcibly.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainSourceArgs', 'DomainSourceArgsDict']]]] sources: the Origin Server Information. See the following `Block sources`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `offline`, `online`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a SCDN Domain resource.

        For information about SCDN Domain and how to use it, see [What is Domain](https://help.aliyun.com/document_detail/63672.html).

        > **NOTE:** Available in v1.131.0+.

        > **NOTE:** Alibaba Cloud SCDN has stopped new customer purchases from January 26, 2023, and you can choose to buy Alibaba Cloud DCDN products with more comprehensive acceleration and protection capabilities. If you are already a SCDN customer, you can submit a work order at any time to apply for a smooth migration to Alibaba Cloud DCDN products. In the future, we will provide better acceleration and security protection services in Alibaba Cloud DCDN, thank you for your understanding and cooperation.

        > **DEPRECATED:**  This resource has been [deprecated](https://www.aliyun.com/product/scdn) from version `1.219.0`.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.scdn.Domain("example",
            domain_name="my-Domain",
            sources=[{
                "content": "xxx.aliyuncs.com",
                "enabled": "online",
                "port": 80,
                "priority": "20",
                "type": "oss",
            }])
        ```

        ## Import

        SCDN Domain can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:scdn/domain:Domain example <domain_name>
        ```

        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 cert_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainCertInfoArgs', 'DomainCertInfoArgsDict']]]]] = None,
                 check_url: Optional[pulumi.Input[str]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 force_set: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainSourceArgs', 'DomainSourceArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            __props__.__dict__["biz_name"] = biz_name
            __props__.__dict__["cert_infos"] = cert_infos
            __props__.__dict__["check_url"] = check_url
            if domain_name is None and not opts.urn:
                raise TypeError("Missing required property 'domain_name'")
            __props__.__dict__["domain_name"] = domain_name
            __props__.__dict__["force_set"] = force_set
            __props__.__dict__["resource_group_id"] = resource_group_id
            if sources is None and not opts.urn:
                raise TypeError("Missing required property 'sources'")
            __props__.__dict__["sources"] = sources
            __props__.__dict__["status"] = status
        super(Domain, __self__).__init__(
            'alicloud:scdn/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            biz_name: Optional[pulumi.Input[str]] = None,
            cert_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainCertInfoArgs', 'DomainCertInfoArgsDict']]]]] = None,
            check_url: Optional[pulumi.Input[str]] = None,
            domain_name: Optional[pulumi.Input[str]] = None,
            force_set: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            sources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainSourceArgs', 'DomainSourceArgsDict']]]]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] biz_name: Attribute perm has been deprecated and suggest removing it from your template.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainCertInfoArgs', 'DomainCertInfoArgsDict']]]] cert_infos: Certificate Information. See the following `Block cert_infos`.
        :param pulumi.Input[str] check_url: The health check url.
        :param pulumi.Input[str] domain_name: The name of domain.
        :param pulumi.Input[str] force_set: Whether to set certificate forcibly.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainSourceArgs', 'DomainSourceArgsDict']]]] sources: the Origin Server Information. See the following `Block sources`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `offline`, `online`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["biz_name"] = biz_name
        __props__.__dict__["cert_infos"] = cert_infos
        __props__.__dict__["check_url"] = check_url
        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["force_set"] = force_set
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["sources"] = sources
        __props__.__dict__["status"] = status
        return Domain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bizName")
    @_utilities.deprecated("""Attribute biz_name has been deprecated and suggest removing it from your template.""")
    def biz_name(self) -> pulumi.Output[Optional[str]]:
        """
        Attribute perm has been deprecated and suggest removing it from your template.
        """
        return pulumi.get(self, "biz_name")

    @property
    @pulumi.getter(name="certInfos")
    def cert_infos(self) -> pulumi.Output[Optional[Sequence['outputs.DomainCertInfo']]]:
        """
        Certificate Information. See the following `Block cert_infos`.
        """
        return pulumi.get(self, "cert_infos")

    @property
    @pulumi.getter(name="checkUrl")
    def check_url(self) -> pulumi.Output[Optional[str]]:
        """
        The health check url.
        """
        return pulumi.get(self, "check_url")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[str]:
        """
        The name of domain.
        """
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter(name="forceSet")
    def force_set(self) -> pulumi.Output[Optional[str]]:
        """
        Whether to set certificate forcibly.
        """
        return pulumi.get(self, "force_set")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The resource group id.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def sources(self) -> pulumi.Output[Sequence['outputs.DomainSource']]:
        """
        the Origin Server Information. See the following `Block sources`.
        """
        return pulumi.get(self, "sources")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource. Valid values: `offline`, `online`.
        """
        return pulumi.get(self, "status")

